summaryrefslogtreecommitdiff
path: root/src/modules/m_shun.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_shun.cpp')
-rw-r--r--src/modules/m_shun.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_shun.cpp b/src/modules/m_shun.cpp
index 5db3c8ef7..391f9a187 100644
--- a/src/modules/m_shun.cpp
+++ b/src/modules/m_shun.cpp
@@ -23,7 +23,7 @@
#include "inspircd.h"
#include "xline.h"
/* $ModDesc: Provides the /shun command, which stops a user executing all commands except PING and PONG. */
class Shun : public XLine
{
@@ -308,7 +308,7 @@ class ModuleShun : public Module
virtual Version GetVersion()
{
- return Version("Provides the /shun command, which stops a user executing all commands except PING and PONG.",VF_VENDOR|VF_COMMON);
+ return Version("Provides the /SHUN command, which stops a user from executing all except configured commands.",VF_VENDOR|VF_COMMON);
}
};
@@ -23,7 +23,7 @@
#include "inspircd.h"
#include "xline.h"
-/* $ModDesc: Provides the /shun command, which stops a user executing all commands except PING and PONG. */
+/* $ModDesc: Provides the /SHUN command, which stops a user from executing all except configured commands. */
class Shun : public XLine
{